aboutsummaryrefslogtreecommitdiff
path: root/include/video.h
diff options
context:
space:
mode:
authorSimon Glass2022-10-06 08:36:08 -0600
committerAnatolij Gustschin2022-10-30 20:01:40 +0100
commit50d562c01ff0a9f500ed9821a74e841d6f6dc133 (patch)
treeeeceaec92a479ba0646c40b94e25d3199679547f /include/video.h
parent820b5894c183c4b68798603f5a96412408e6b8cf (diff)
video: Allow filling the display with a colour
Generalise the video_clear() function to allow filling with a different colour. Tidy up the comments while we are here. Signed-off-by: Simon Glass <sjg@chromium.org>
Diffstat (limited to 'include/video.h')
-rw-r--r--include/video.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/include/video.h b/include/video.h
index 1c30aea73c0..4c216d851b6 100644
--- a/include/video.h
+++ b/include/video.h
@@ -185,14 +185,23 @@ u32 video_index_to_colour(struct video_priv *priv, unsigned int idx);
int video_reserve(ulong *addrp);
/**
* video_clear() - Clear a device's frame buffer to background color.
*
* @dev: Device to clear
- * Return: 0
+ * Return: 0 on success
*/
int video_clear(struct udevice *dev);
/**
+ * video_fill() - Fill a device's frame buffer to a colour.
+ *
+ * @dev: Device to fill
+ * @colour: Colour to use, in the frame buffer's format
+ * Return: 0 on success
+ */
+int video_fill(struct udevice *dev, u32 colour);
+
+/**
* video_sync() - Sync a device's frame buffer with its hardware
*
* @vid: Device to sync
@@ -185,14 +185,23 @@ u32 video_index_to_colour(struct video_priv *priv, unsigned int idx);
int video_reserve(ulong *addrp);
/**
- * video_clear() - Clear a device's frame buffer to background color.
+ * video_clear() - Clear a device's frame buffer to background colour.
*
* @dev: Device to clear